import java.util.ArrayList;
import java.util.HashSet;

/**
 * Voting System
 */
public class VotingSystem {

    private ArrayList<Voting> votingList;

    /**
     * Constructor
     */
    public VotingSystem() {
        this.votingList = new ArrayList<>();
    }

    /**
     * @param type of voting. 0 is single and 1 is multiple
     * @param question for voting
     * @param optionsList for voting
     * @return a vote
     */
    public Voting createVoting(int type, String question, ArrayList<String> optionsList) {
        HashSet<String> optionsSet = new HashSet<>(optionsList);
        Voting voting = new Voting(type, question, optionsSet);
        this.votingList.add(voting);
        return voting;
    }


    /**
     * @return a list of votings
     */
    public ArrayList<Voting> getVotingList() {
        return votingList;
    }


    /**
     * @param type type of voting
     * @return a list of voting by type
     */
    public ArrayList<Voting> getVoting(int type) {
        ArrayList<Voting> sameVoting = new ArrayList<>();

        for (Voting voting : this.votingList) {
            if (voting.getType() == type) {
                sameVoting.add(voting);
            }
        }
        return sameVoting;
    }


    /**
     * @param voting vote to a specific option
     * @param person the voter
     * @param selectedOptions options which are selected
     */
    public void vote(Voting voting, Person person, ArrayList<String> selectedOptions) {
        voting.vote(person, selectedOptions);
    }


    public void vote(Voting voting, Person person, String selectedOption) {
        voting.vote(person, selectedOption);
    }


    public void printVotingResult(Voting voting, int type) {
        System.out.println(voting.getQuestion());
        voting.printVotes(type);
    }
}